@@ -119,7 +119,8 @@ def aws_get_region():
         return region
     try:
         r = requests.get(
-            'http://169.254.169.254/latest/dynamic/instance-identity/document')
+            'http://169.254.169.254/latest/dynamic/instance-identity/document',
+            timeout=5)
         return r.json().get('region')
     except Exception:
         return None
@@ -206,7 +207,8 @@ def get_region():
         return region
     try:
         r = requests.get(
-            'http://169.254.169.254/latest/dynamic/instance-identity/document')
+            'http://169.254.169.254/latest/dynamic/instance-identity/document',
+            timeout=5)
         return r.json().get('region')
     except Exception:
         return None
@@ -258,6 +260,7 @@ def get_ec2_instances(**filter_opts):
     """
     filters = [{'Type': 'TERM_MATCH', 'Field': k, 'Value': v}
                for k, v in filter_opts.items()]
+    filters.append({'Type': 'TERM_MATCH', 'Field': 'locationType', 'Value': 'AWS Region'})
 
     # currently the pricing API is limited to some regions, so don't waste time
     # on trying to access it on others one by one
@@ -281,7 +284,7 @@ def get_ec2_defined_duration_prices():
     the parsing process.
     """
 
-    r = requests.get(spot_js)
+    r = requests.get(spot_js, timeout=5)
     # this is JavaScript, so we have to parse data out from it
     js = r.text
     data = json.loads(js[js.find('{'):js.rfind('}')+1])
@@ -334,7 +337,7 @@ def get_ec2_prices(fail_on_missing_regions=False, **filter_opts):
         DataFrame with instance attributes and pricing
 
     """
-    from cloudperf.providers.aws import region_map, location_map
+    from cloudperf.providers.aws import region_to_location, location_to_region
     prices = []
     params = {}
 
@@ -354,9 +357,8 @@ def get_ec2_prices(fail_on_missing_regions=False, **filter_opts):
             continue
         vcpu = int(data['product']['attributes']['vcpu'])
         memory = aws_parse_memory(data['product']['attributes']['memory'])
-        try:
-            region = region_map[data['product']['attributes']['location']]
-        except KeyError:
+        region = location_to_region(data['product']['attributes']['location'])
+        if not region:
             missing_regions.add(data['product']['attributes']['location'])
         params[instance_type] = data['product']['attributes']
         params[instance_type].update({'vcpu': vcpu, 'memory': memory, 'region': region,
@@ -367,10 +369,8 @@ def get_ec2_prices(fail_on_missing_regions=False, **filter_opts):
         prices.append(d)
 
     if fail_on_missing_regions and missing_regions:
-        print('The following regions are missing from aws.region_map, please '
-              'update (for eg. from https://aws.amazon.com/ec2/pricing/on-demand/, '
-              'inspecting the region dropdown, or '
-              'https://docs.aws.amazon.com/general/latest/gr/rande.html)')
+        print("The following regions are missing from botocore's endpoints.json and from "
+              "the baked-in region_map")
         print(*missing_regions, sep='\n')
         sys.exit(1)
 
@@ -389,7 +389,7 @@ def get_ec2_prices(fail_on_missing_regions=False, **filter_opts):
             instance_type = data['InstanceType']
             d = copy.deepcopy(params[instance_type])
             d.update({'price': float(data['SpotPrice']), 'spot': True, 'spot-az': data['AvailabilityZone'], 'region': region})
-            d.update({'location': location_map[region]})
+            d.update({'location': region_to_location(region)})
             for duration, price in DictQuery(block_prices).get([region, instance_type], {}).items():
                 # add spot blocked duration prices, if any
                 d.update({f'price_{duration}h': price})
